==> haskell-hledger_0.27.orig.tar.gz: hledger-0.27/README.md <==
#  hledger

## lightweight, portable, dependable accounting tools

hledger is a computer program for easily tracking money, time, or other commodities,
on unix, mac and windows (and web-capable mobile devices, to some extent).

It is first a command-line tool, but there are also curses-style and
web interfaces, and a Haskell library
(http://hackage.haskell.org/package/hledger-lib) for building your own
programs and scripts (hledger is written in Haskell).  hledger was
inspired by and is largely compatible with Ledger.  hledger is free
software available under the GNU General Public License v3+.

hledger aims to help both computer experts and regular folks
to gain clarity and control in their finances and time management,
but currently it is a bit more suited to techies.
I use it every day to:

-   track spending and income
-   see time reports by day/week/month/project
-   get accurate numbers for client billing and tax filing
-   track invoices

Though limited in features, hledger is lightweight, usable and reliable.
For some, it is a simpler, less distracting, more future-proof alternative to Quicken or GnuCash.

For more, see http://hledger.org.

[![license](https://img.shields.io/badge/license-GPLv3+-brightgreen.svg)](http://www.gnu.org/licenses/gpl.html)
[![hackage release](https://img.shields.io/hackage/v/hledger.svg?label=current+release)](http://hackage.haskell.org/package/hledger)
<!-- [![github release](https://img.shields.io/github/release/simonmichael/hledger.svg?label=github+release)](https://github.com/simonmichael/hledger/releases) -->
<!-- [![github latest release downloads](https://img.shields.io/github/downloads/simonmichael/hledger/latest/total.svg?label=github+downloads)](https://github.com/simonmichael/hledger/releases) -->
<!-- [![gratipay](https://img.shields.io/gratipay/hledger.svg)]() -->

[![travis build status](https://img.shields.io/travis/simonmichael/hledger.svg)](https://travis-ci.org/simonmichael/hledger)
[![hackage upper bounds](https://img.shields.io/hackage-deps/v/hledger.svg?label=hackage+bounds)](http://packdeps.haskellers.com/feed?needle=hledger)
[![github issues](https://img.shields.io/github/issues/simonmichael/hledger.svg)](http://bugs.hledger.org)
[![bountysource](https://api.bountysource.com/badge/team?team_id=75979&style=bounties_received)](https://github.com/simonmichael/hledger/issues?q=label:bounty)

==> haskell-hledger_1.0.1.orig.tar.gz: hledger-1.0.1/README.md <==
#  hledger

## lightweight, portable, dependable accounting tools

hledger is a computer program for easily tracking money, time, or other commodities,
on unix, mac and windows (and web-capable mobile devices, to some extent).

It is first a command-line tool, but there are also curses-style and
web interfaces, and a Haskell library
(http://hackage.haskell.org/package/hledger-lib) for building your own
programs and scripts (hledger is written in Haskell).  hledger was
inspired by and is largely compatible with Ledger.  hledger is free
software available under the GNU General Public License v3+.

hledger aims to help both computer experts and regular folks
to gain clarity and control in their finances and time management,
but currently it is a bit more suited to techies.
I use it every day to:

-   track spending and income
-   see time reports by day/week/month/project
-   get accurate numbers for client billing and tax filing
-   track invoices

Though limited in features, hledger is lightweight, usable and reliable.
For some, it is a simpler, less distracting, more future-proof alternative to Quicken or GnuCash.

For more, see http://hledger.org.

[![license](https://img.shields.io/badge/license-GPLv3+-brightgreen.svg)](http://www.gnu.org/licenses/gpl.html)
[![hackage release](https://img.shields.io/hackage/v/hledger.svg?label=current+release)](http://hackage.haskell.org/package/hledger)
[![stackage LTS package](http://stackage.org/package/hledger/badge/lts)](http://stackage.org/lts/package/hledger)
<!-- [![github
release](https://img.shields.io/github/release/simonmichael/hledger.svg?label=github+release)](https://github.com/simonmichael/hledger/releases)
--> <!-- [![github latest release
downloads](https://img.shields.io/github/downloads/simonmichael/hledger/latest/total.svg?label=github+downloads)](https://github.com/simonmichael/hledger/releases)
--> <!-- [![gratipay](https://img.shields.io/gratipay/hledger.svg)]()
-->

[![travis build status](https://img.shields.io/travis/simonmichael/hledger.svg)](https://travis-ci.org/simonmichael/hledger)
[![hackage upper bounds](https://img.shields.io/hackage-deps/v/hledger.svg?label=hackage+bounds)](http://packdeps.haskellers.com/feed?needle=hledger)
[![github issues](https://img.shields.io/github/issues/simonmichael/hledger.svg)](http://bugs.hledger.org)
[![bountysource](https://api.bountysource.com/badge/team?team_id=75979&style=bounties_received)](https://github.com/simonmichael/hledger/issues?q=label:bounty)
